Tento text byl publikován jako součást knihy (Lopatková et al., 2016) vydané nakladatelstvím Karolinum.

# Valence sloves a její zachycení ve slovníku VALLEX

# Úvod

Jazykový popis se tradičně dělí na dvě základní složky: gramatiku a lexikon. Gramatika popisuje zákonitosti přirozeného jazyka pomocí pravidel, která lze uplatnit na celé třídy slov, zatímco lexikon představuje inventář lexikálních jednotek s jejich specifickými charakteristikami.

Valence je typickým příkladem jazykového jevu na hranici mezi gramatikou a lexikonem. Valencí se označuje schopnost lexikální jednotky vázat na sebe určitý počet závislých jednotek. Její zásadní pozice v jazykovém systému je dána tím, že ačkoli jde o vlastnost lexikálně podmíněnou, sehrává centrální úlohu v syntaxi při utváření větné struktury (Sgall, 2006). Valence se primárně vztahuje k významové rovině jazyka, tedy k hloubkové větné stavbě. Vyznačují se jí autosémantické slovní druhy: substantiva, adjektiva, některá adverbia a zejména slovesa, jež díky své valenci vytvářejí centrum věty.

Termín valence v lingvistické literatuře poprvé užil v polovině 20. století francouzský syntaktik Lucien Tesnière (1959). V současnosti náleží valence ke klíčovým konceptům mnoha lingvistických teorií, a to nejen teorií založených na závislostní koncepci, jmenujme za všechny Model Smysl↔Text (Mel'čuk, 1988) a Funkční generativní popis (Sgall et al., 1986b). Koncept valence dnes sehrává zásadní roli i ve vlivných postgenerativních teoriích, jako jsou Lexikálně-funkční gramatika (LFG) (Bresnan, 1982; Bresnan, 2001), Head-driven Phrase Structure Grammar (HPSG) (Pollard – Sag, 1994) nebo Tree Adjoining Grammar (TAG) (Joshi et al., 1975; Joshi, 1985).1

Zhruba od 90. let 20. století jsou valenční teorie aplikovány na velká jazyková data. Lexikální zdroje obsahující informaci o valenci jsou vytvářeny s ohledem na možnosti dalšího využití valenční charakteristiky sloves (i dalších slovních druhů) jednak při budování syntakticky anotovaných korpusů (jako jsou níže zmíněné korpusy Penn Treebank a Pražský závislostní korpus (PDT)), jednak v nástrojích pro zpracování přirozeného jazyka. Valence hraje zásadní roli především v těch aplikacích, které pracují s významem, např. ve strojovém překladu, sumarizaci textu a automatické desambiguaci významů, pro něž jsou základními předpoklady syntaktická analýza a rozlišení významů jednotlivých slov. Formalizace, která tvorbu lexikálních zdrojů nutně provází, zároveň umožňuje ověření a kontrolu bezrozpornosti, konzistentnosti a teoretické i empirické adekvátnosti přijatých základních postulátů a jejich případnou modifikaci.

Pro ilustraci uveďme některé významné zahraniční projekty zaměřené na popis valence. PropBank 2 je anglický projekt zaměřený na anotaci predikátových argumentových struktur sloves z Penn Treebanku3 (Kingsbury et al., 2002; Palmer et al., 2005). Tento projekt zohledňuje především syntaktické chování sloves. Argumenty sloves jsou obohaceny o sémantické role uložené v lexikální databázi VerbNet,4 která vychází ze sémantické klasifikace sloves vytvořené B. Levinovou (Levin, 1993). Sémantické třídy vymezené Levinovou jsou ve VerbNetu dále subklasifikovány a opatřeny syntaktickou informací (Kipper et al., 2006). Jak PropBank, tak VerbNet je propojen v rámci projektu SemLink 5 (Palmer, 2009) s lexikální databází FrameNet,6 která představuje další sémanticky orientovaný lexikální zdroj, popisující valenci nejen anglických sloves, ale i substantiv, adjektiv a adverbií (Baker et al., 1998; Fillmore et al., 2002; Ruppenhofer et al., 2006).

Z lexikálních zdrojů popisujících slovanské jazyky jmenujme především Explanatory Combinatorial Dictionary of Modern Russian (Mel'čuk – Zholkovsky, 1984), představující lexikální komponentu Modelu Smysl↔Text (Mel'čuk, 1988). Tento slovník, zachycující kromě syntagmatických vztahů (odpovídajících valenci) též paradigmatické vztahy mezi lexikálními jednotkami, patří bezesporu k nejpropracovanějším valenčním slovníkům. V současnosti vzniká rozsáhlá lexikální databáze polských sloves Walenty 7 s informací o subkategorizačních rámcích sloves doplněná o některé další syntaktické rysy (Przepiórkowski et al., 2014). Z polských valenčních slovníků jmenujme ještě rozsáhlý Słownik syntaktyczno-generatywny czasowników polskich s explicitním popisem valenční struktury polských sloves (Polański, 1980–1992). Bulharština má k dispozici do elektronické verze konvertovaný valenční slovník tisíce nejčastějších bulharských sloves vzniklý na konci 80. let (Popova, 1987; Balabanova – Ivanova, 2002). Pro slovenštinu byl na základě korpusového materiálu vytvořen Valenčný slovník slovenských slovies na korpusovom základe (Ivanová et al., 2014), navazující na Valenčný slovník slovenských slovies (Nižníková – Sokolová, 1998) a na Valenčný slovník slovenských slovies 2. zväzok (na korpusovom základe) (Nižníková, 2006), do něhož se promítly nové teoretické poznatky z oblasti valence a detailně vypracovaná sémantická klasifikace sloves.

Předkládaný Valenční slovník českých sloves (dále též VALLEX 3.0) 8 poskytuje informace o valenční struktuře českých sloves v jejich jednotlivých významech, které charakterizuje pomocí glos a příkladů; tyto základní údaje jsou doplněny o některé další syntaktické a sémantické charakteristiky. VALLEX 3.0 zachycuje 4 586 českých sloves náležejících 2 722 lexémům, které odpovídají 6 711 lexikálním jednotkám, tedy „daným slovesům v daném významu“ (počítáme-li vidové protějšky zvlášť, jde – bez iterativ, jež nejsou detailně zpracována – o 10 821 lexikálních jednotek).

Z českých valenčních slovníků dále uveďme především dva tištěné slovníky Slovesa pro praxi (Svozilová et al., 1997) a Slovník slovesných, substantivních a adjektivních vazeb a spojení (Svozilová et al., 2005), vycházející z Danešovy koncepce větných vzorců (Daneš – Hlavsa, 1987). Z elektronických slovníků jmenujme (bohužel nikdy nezveřejněný) plně automaticky vytvořený Český syntaktický lexikon; tento slovník, vycházející z teoretického zázemí Funkčního generativního popisu, obsahuje kromě informace o valenční struktuře sloves též informaci o diatezích, reflexivitě a kontrole (Skoumalová, 2001). Stejný teoretický aparát využívá i slovník PDT-Vallex 9 (Hajič et al., 2003; Urešová, 2011), popisující valenční charakteristiku všech výskytů sloves (a dále některých jmen a adjektiv) v Pražském závislostním korpusu10 (PDT). Pro češtinu byla dále vyvinuta lexikální databáze VerbaLex, využívající konceptu synsetů (řad synonymních lexikálních jednotek sloves) z české verze EuroWordNetu, které byly obohaceny o informaci o jejich valenční struktuře (Hlaváčková – Horák, 2005; Hlaváčková, 2008).

# Valenční charakteristika sloves

Při popisu valenční charakteristiky sloves vycházíme z valenční teorie Funkčního generativního popisu (FGP, viz zvláště Sgall, 1967; Sgall et al., 1986a), která navazuje na klasickou evropskou lingvistiku, především na L. Tesnièra (1959), a částečně na studie Fillmorovy (1968; 1977). Stručně zde shrneme základní principy této valenční teorie, vypracované zejména J. Panevovou (1974–75; 1980).

Valence ve FGP primárně přináleží tektogramatické rovině, tedy rovině významové (hloubkové) stavby věty (k tektogramatické rovině viz především Sgall et al., 1986a). S valencí slovesa je spojena dvojí distinkce, a to (i) rozdíl mezi aktanty (argumenty, vnitřními doplněními) a volnými doplněními (adjunkty) a (ii) rozdíl mezi doplněními obligatorními a fakultativními.

## 1 Aktanty a volná doplnění ve FGP

Valenční doplnění jsou ve FGP jednotkami tektogramatické roviny a jsou chápána jako funkce větných členů roviny povrchové syntaxe. Valenční doplnění jsou tříděna na aktanty a volná doplnění. Mezi aktanty patří doplnění tradičně chápaná jako objektová a dále ta doplnění, jejichž protějškem je povrchový subjekt. Volná doplnění jsou především doplnění adverbiálního typu. 11 Určitý druh doplnění je pak aktantem nebo volným doplněním ve všech svých výskytech. Doplnění jsou označována tzv. funktory, udávajícími typ syntakticko-sémantického vztahu valenčního doplnění k řídícímu slovesu.

FGP při studiu valence klade důraz na práci s operativními (testovatelnými) kritérii. Kritéria pro třídění slovesných valenčních doplnění byla formulována zejména Panevovou (1974–75; 1980):

- Může dané doplnění rozvíjet jedno sloveso (jeden jeho výskyt) víc než jednou (odhlížíme-li od koordinace a apozice)?

- Může dané doplnění rozvíjet (a) jakékoli sloveso (odhlížíme-li od obsahových omezení), nebo (b) jen některá slovesa tvořící omezenou skupinu, která mohou být specifikována výčtem?

Pokud doplnění může rozvíjet dané sloveso jen jednou a odpovídá charakteristice (iib), jde o aktant. FGP na základě empirických zkoumání rozlišuje celkem pět aktantů: Konatel / Aktor (dále též ACT), Patiens (PAT), Adresát (ADDR), Výsledek děje / Efekt (EFF) a Původ (ORIG). Aktanty jsou pro určité sloveso charakteristické, představují tak konstitutivní prvky jeho valenční struktury, např. Matěj.ACT daroval dětem.ADDR mapu.PAT. Prezident.ACT ho.PAT jmenoval generálem.EFF. Petra.PAT od ní.ORIG dělily dva roky.ACT. Podrobnější charakteristiku aktantů uvádíme níže.

Pro volná doplnění platí specifika (i) a (iia): volné doplnění může rozvíjet jakékoli sloveso (omezení na slučitelnost slovesa a volného doplnění je dáno spíše obsahovými vztahy než syntaktickými rysy), a to i více než jedenkrát, např. Včera.TWHEN večer.TWHEN jsem šel pozdě.TWHEN spát., Prostírání najdeš v příborníku.LOC ve druhé polici.LOC dole.LOC. K valenční struktuře slovesa (v užším slova smyslu) volná doplnění náleží pouze tehdy, pokud je jejich výskyt obligatorní (viz níže), srov. valenční doplnění místa LOC ve větě Na zimu ptáky umístí v zateplené místnosti.LOC. vs. nevalenční LOC Pracoval na zahradě.LOC. Volná doplnění jsou (na rozdíl od aktantů) sémanticky distinktivní. Jejich úplný seznam lze najít v monografii Panevové et. al (2014); seznam volných doplnění, která mohou být valenční, je uveden níže v odd. GUIDE > 3.2 (a to včetně jejich prototypické morfematické charakteristiky).

Další rozdíl mezi aktanty a volnými doplněními se týká jejich povrchové realizace: zatímco aktanty v povrchové struktuře věty obvykle nabývají vlivem slovesa určité formy, tj. jejich morfematické vyjádření je určováno požadavky řídícího slovesa (tzv. rekcí) (např. rozbít sklenici, bránit výstavbě, doufat ve vítězství), forma volných doplnění typicky není řízena slovesem, ale bývá dána jejich významem, např. děti přišly domů / do školy / na hřiště.

Vedle těchto dvou typů závislostních vztahů, tedy aktantů a volných doplnění, je vhodné uvažovat též o třetím typu, o tzv. kvazivalenčních doplněních, která vykazují hybridní chování: sdílejí některé rysy s aktanty (i)–(iii) a jiné s volnými doplněními (iv)–(vi) (více viz Lopatková – Panevová, 2006; Panevová et al., 2014):

- jde o rekční doplnění sloves,

- vyskytují se u omezené skupiny sloves,

- jeden výskyt slovesa nemohou rozvíjet více než jedenkrát,

- jsou sémanticky homogenní,

- nepodléhají tzv. posouvání (viz následující oddíl) a

- ve většině případů jsou fakultativní (test pro rozlišení obligatorních a fakultativních doplnění představujeme níže).

Rysy kvazivalenčních doplnění vykazují následující typy doplnění: Překážka (OBST), např. poranit se o střep.OBST, Prostředník (MED), např. zatahat někoho za rukáv.MED,12 Rozdíl (DIFF), např. inflace se zvýšila o 5 %.DIFF, a Záměr (INTT), např. jít do lesa na jahody.INTT, jít nakoupit.INTT.

### 1.1 Princip „kognitivního“ posouvání

Při klasifikaci aktantů se u slovesa v daném významu přihlíží k počtu aktantů, k jejich sémantice (týká se především třetího až pátého aktantu), k analogii s dalšími slovesy a též k jejich morfematické realizaci. V zásadě platí, že první dva aktanty, ACT a PAT, jsou určovány syntakticky, zatímco pro určení dalších aktantů se zohledňují sémantická kritéria. FGP se tak vyhýbá dvěma krajnostem: (i) subjektivismu v určování doplnění pouze na základě sémantických rysů doplnění bez ohledu na jeho povrchovou realizaci (Fillmore, 1968; Fillmore, 1977) a (ii) čistě syntaktickému vymezení doplnění, které nezohledňuje vztah doplnění ke slovesu (Tesnière, 1959).

U slovesa s jediným aktantem je tento aktant označen jako ACT bez ohledu na to, jakou kognitivní roli nese s ním korespondující situační participant,13 srov. Kameníci.ACT drtili kámen na drobný štěrk., Petr.ACT se chvěje zimou., Otec.ACT trpěl bolestmi., Vítr.ACT rozbil okno. i Okno.ACT se rozbilo. (kde jako ACT označujeme doplnění odpovídající participantům s kognitivními rolemi „Agens“, „Nositel děje“, „Nositel stavu“, „Kauzátor“ a „Zasažený objekt“). Sloveso se dvěma aktanty pak má ve valenčním rámci vždy ACT a PAT, např. Jan.ACT rozbil vázu.PAT., Kniha.ACT patří Petrovi.PAT. a Jan.ACT blahopřál Petrovi.PAT k narozeninám. bez ohledu na sémantickou interpretaci, která plyne z lexikální povahy slovesa a slova, jež pozici aktantu zaujímá (zde jako PAT označen po řadě „Zasažený objekt“, „Posesor“ a „Recipient“).

Pokud tedy sloveso ve své sémantické struktuře participant s rolí „Agenta“, „Nositele děje / stavu“, „Kauzátora“ a/nebo „Zasažený objekt“ nemá, podléhají jeho aktanty tzv. kognitivnímu posouvání: u slovesa s jedinou valenční pozicí je daný aktant strukturován jako ACT; u slovesa se dvěma pozicemi jsou aktanty strukturovány jako ACT a PAT; slovesa se třemi a více valenčními pozicemi mají v rámci nutně ACT a PAT, u dalších valenčních pozic rozhoduje sémantika slovesa, sémantika jeho doplnění (a částečně i jejich morfematická forma), např. Kniha.ACT vyšla. (jako ACT je strukturován aktant odpovídající participantu s kognitivní rolí „Zasaženého objektu“), Váza.ACT se rozbila. (ACT jako „Zasažený objekt“) a Otec postavil dům.PAT z cihel. (PAT jako „Výsledek děje“), Jeník vyrostl z chlapce v muže.PAT. (PAT jako „Výsledek děje“), Nemoc pochází z viru.PAT. (PAT jako „Původce stavu“), Petr bratrovi.PAT věřil. (PAT jako „Recipient“), Agentura Baltic News Service patří severským firmám.PAT. (PAT jako „Posesor“) (více viz zejména Panevová et al., 2014).

### 1.2 Charakteristika aktantů

Aktanty lze na základě výše zmíněných principů charakterizovat následujícím způsobem:

- Aktor / Konatel (funktor ACT). Valenční doplnění Konatel je (levovalenční) aktant, který je vymezen jako první aktant slovesa – označuje doplnění zaplňující první syntaktickou pozici slovesa, např. Maminka.ACT upekla koláč., Voda.ACT naplnila jámu., Kniha.ACT vyšla. Jedná se o doplnění v aktivní konstrukci typicky vyjadřované v povrchověsyntaktické pozici subjektu (v případě pasivní konstrukce se jedná o doplnění se stejným sémantickým vztahem ke slovesu, např. Nakladatelství.ACT Odeon vydalo knihu. i Kniha byla vydána nakladatelstvím.ACT Odeon.). Ze sémantického hlediska Konatel typicky odpovídá široce pojatému „Agentu“, „Nositeli děje / stavu“, „Kauzátoru“, příp. „Proživateli“.

  Je-li jeden z aktantů vyjádřen dativní nebo akuzativní formou (a druhý nominativní formou), přihlíží se též k sémantice aktantu: vyjadřuje-li aktant s dativní či akuzativní formou „Proživatele“, hodnotí se tento aktant jako Konatel (a aktant v nominativu jako Patiens), např. Kniha se mi.ACT líbila., Bolela ho.ACT hlava.

- Patiens (funktor PAT). Valenční doplnění Patiens je (pravovalenční) aktant, který je vymezen jako druhý aktant slovesa – označuje doplnění zaplňující druhou syntaktickou pozici slovesa, např. Marie postavila vázu.PAT na stůl., Maminka upekla koláč.PAT., Kniha patří Janovi.PAT., Jan se vzdal odměny.PAT., Petr se učil zahradníkem.PAT., Vyprávěl nám o dovolené.PAT. Jedná se o doplnění v aktivní konstrukci prototypicky vyjadřované v povrchověsyntaktické pozici přímého objektu (v případě pasivní konstrukce se jedná o doplnění se stejným sémantickým vztahem, např. Nakladatelství Odeon vydalo knihu.PAT. i Kniha.PAT byla vydána nakladatelstvím Odeon.). Sémanticky Patiens prototypicky koresponduje s participantem s kognitivní rolí „Zasaženého objektu“.

  Vyjadřuje-li aktant realizovaný dativní nebo akuzativní formou „Proživatele“ a má-li druhý aktant formu nominativu, hodnotí se aktant v nominativu jako Patiens (a dativní nebo akuzativní aktant jako Konatel), např. Kniha se mi líbila.PAT., Bolela ho hlava.PAT.

- Výsledek děje / Efekt (funktor EFF). Valenční doplnění Efekt je (pravovalenční) aktant, který se uplatňuje u sloves se třemi (a více) syntaktickými pozicemi. Funktor EFF je přiřazován zejména doplněním obsazujícím třetí syntaktickou pozici u sloves; tato pozice odpovídá jednak „doplňku doplňovacímu“ (viz doplněk u tzv. sloves neplnovýznamových, Šmilauer, 1966), jednak jde o druhý věcný předmět sémanticky odpovídající „Výsledku děje“. Obecně vyjadřuje vlastnost nebo stav, které má za jistého děje entita odpovídající Patientu nebo které se mu jistým dějem přisuzují, např. Považoval Pavla za odborníka.EFF., Jmenovali ho ředitelem.EFF., My tomu říkáme efekt.EFF sněhové koule., Petr přeložil knihu do češtiny.EFF., Svazovali kmeny do voru.EFF.

- Adresát (funktor ADDR). Valenční doplnění Adresát je (pravovalenční) aktant, který je vymezen jako aktant slovesa typicky vyjadřující participant s kognitivní rolí „Recipienta“, např. Otec dal dceři.ADDR k narozeninám knížku., Řekl synovi.ADDR pravdu., Bratrovi.ADDR nezaplatili dohodnutou mzdu., Celé dětství soupeřil o matčinu přízeň s bratrem.ADDR. Funktor ADDR se uplatňuje u sloves se třemi (a více) valenčními pozicemi. Jeho charakteristickým rysem je životnost. Typicky jde o doplnění vyjadřované v povrchověsyntaktické pozici nepřímého objektu, např. Předal knihu Janovi.ADDR., Kniha byla předána Janovi.ADDR.

- Původ (funktor ORIG). Valenční doplnění Původ je (pravovalenční) aktant, který je vymezen jako aktant slovesa vyjadřující participant s kognitivní rolí „Původce děje / stavu“, např. Vyrábějí ze dřeva.ORIG stoly i židle., Slyšel o neštěstí od sousedů.ORIG., Nevzal od něj.ORIG za práci peníze. Funktor ORIG se uplatňuje u sloves se třemi (a více) valenčními pozicemi.

### 1.3 Obligatornost vs. fakultativnost: dialogový test

Druhou distinkcí spojenou s valencí je rozdíl mezi doplněními obligatorními a fakultativními; tato distinkce reflektuje různou významovou těsnost jednotlivých doplnění.

Neobsazením některých pozic dochází k porušení významové úplnosti, což může vést i k porušení gramatické správnosti věty, např. *Petr dává., *Marie nenávidí., *Jan se choval. Doplnění obsazující takové valenční pozice se nazývají obligatorní.14 Jiné valenční pozice jsou sice pro dané sloveso charakteristické, jejich neobsazením však nevzniká významově ani gramaticky narušená věta, např. Zvonila (na něj), nikdo ale nepřišel otevřít., Eva se najedla (ovoce)., Dívka píše (mamince) dopis. Takové valenční pozice se označují jako fakultativní.

Ostatní pozice s velmi volným vztahem ke slovesu bývají obvykle označovány jako volné či též fakultativní, např. Jana se procházela (po lese)., Petr se budil (časně)., Eva si četla (pro své potěšení)., i když v teoretickém popisu bývají do valence slovesa (v širším smyslu) též často zahrnovány.

Pro určení obligatornosti a fakultativnosti doplnění se ve FGP používá tzv. dialogový test formulovaný Panevovou (Panevová, 1974–75; viz též Panevová, 1980). Dialogový test se užívá zejména k potvrzení nebo vyvrácení hypotézy, že určité doplnění je významově obligatorní, avšak není přítomno (tj. je vypuštěno) na rovině povrchové syntaxe. Dialogový test využívá podstatného rozdílu mezi otázkou po něčem, co má být posluchači známé, a otázkou po doplňující informaci. Na otázku po obligatorním členu slovesa mluvčí nemůže odpovědět Nevím. Dialogový test lze demonstrovat na následujícím dialogu:
A: Jan právě přišel.
B: Kam?
A: *Nevím.

Takový dialog se nejeví jako smysluplný. Bylo by ho možné pokládat za smysluplný jen za určitých okolností, kdy se posluchač přeslechl nebo je z kontextu zřejmé, že jeho otázka Kam? je eliptická (posluchač ví, na jaké místo Jan přišel, ale ptá se po bližším určení místa). Otázka Kam? tak má zcela jiný charakter než otázky po doplňující informaci typu Odkud?, Proč? apod. Odpovědi Nevím. na otázku po doplňující informaci nečiní dialog nijak deviantním, srov.:
A: Jan právě přišel.
B: Odkud? / Proč? / S kým?
A: Nevím.

Jestliže odpověď Nevím. na otázku po určitém doplnění slovesa není možná, je takové doplnění chápáno jako doplnění na tektogramatické rovině obligatorní, které však může být z povrchové struktury věty za určitých podmínek vypuštěno.

Dialogovým testem lze také zjistit, že určitá doplnění objektového typu (odpovídající aktantům, viz výše) nejsou dle uvedeného testu obligatorní, ačkoli je zřejmé, že patří k valenčnímu rámci slovesa; smysluplnost dialogu není odpovědí Nevím. porušena v případě, že mluvčí odpovídá posluchači na otázku po fakultativním aktantu. Při otázce po obligatorních aktantech odpověď mluvčího Nevím. možná není, srov.:
A: Koupil nové auto.
B: Od koho?
A: Nevím.
B: Kdo?
A: *Nevím.

### 1.4 Valenční rámec ve FGP

Do struktury valenčního rámce patří všechny aktanty bez ohledu na jejich obligatornost a ta volná doplnění, která jsou obligatorní; v tomto smyslu lze hovořit o standardním valenčním rámci. Tento standardní valenční rámec je vhodné dále rozšířit o kvazivalenční doplnění (obligatorní i fakultativní).

Lze tedy rozlišovat doplnění valenční (aktanty a obligatorní volná doplnění) a doplnění kvazivalenční (doplnění těchto dvou typů tvoří obohacený valenční rámec), a dále doplnění nevalenční (fakultativní volná doplnění). Předpokládáme, že fakultativní volná doplnění mohou být specifikována pro celé sémantické skupiny sloves jako jejich typická rozvití.

### 1.5 Zachycení valence ve VALLEXu

Centrálním pojmem, ze kterého slovník VALLEX při popisu valenční charakteristiky sloves vychází, je pojem lexému15 (Filipec – Čermák, 1985; Cruse, 1986). Lexém zde chápeme jako abstraktní formálně-významovou jednotku usouvztažňující:

1. formální složku, tj. množinu všech slovesných forem, a

2. významovou složku, reprezentovanou množinou lexikálních jednotek 16 odpovídajících jednotlivým významům slovesa.

Lexikální formy jsou tedy všechny morfematické formy slovesa (celé jeho paradigma), zatímco lexikální jednotky chápeme jako „komplexní jednotky s (relativně) stálými, diskrétními sémantickými vlastnostmi“ (Cruse, 1986), které nesou informaci o syntaktických a sémantických rysech slovesa v určitém významu; stručně řečeno jde o „dané slovo v daném významu“ (obr. 1).

Obrázek 1: Lexém, slovesné formy a lexikální jednotky (sloveso odpovídatimpf — odpovědětpf).

Valenční charakteristika je vlastní jednotlivým významům slovesa, tedy jednotlivým lexikálním jednotkám (nikoli celému lexému), např. Petr dětem odpovídá na otázky smíchem. (lexikální jednotka s významem „dávat odpověď“), Pokožka odpovídá na podráždění zarudnutím. (lexikální jednotka s významem „reagovat“), Rodiče odpovídají za své děti. (lexikální jednotka s významem „mít odpovědnost“) a Navrhované řešení odpovídá požadavkům zadavatele. (lexikální jednotka s významem „být ve shodě / v souladu; korespondovat“). Každá lexikální jednotka ve VALLEXu tedy nese svou valenční charakteristiku ve formě (právě jednoho) valenčního rámce.17

Valenční rámec – ve shodě s valenční teorií FGP – sestává ze sledu valenčních pozic, charakterizovaných funktorem a obligatorností. K této základní informaci (náležící tektogramatické rovině) přistupuje též informace o morfematické formě; morfematická vyjádření určující povrchověsyntaktickou realizaci (rekčních) valenčních doplnění odpovídají nepříznakovým užitím slovesa, tedy jeho užitím v aktivním, nerecipročním a nereflexivním tvaru,18 např. sloveso odpovídatimpf — odpovědětpf ve významu „mít odpovědnost“ je charakterizováno valenčním rámcem ACT1 ADDR3 PATza+4, sloveso zaplatitpf ve významu „poskytnout platbu“ má valenční rámec ACT1 ADDR3 PAT4 EFFod+2, za+4. (Povrchová) vypustitelnost valenčních doplnění ve slovníku VALLEX zachycena není.

Valenční rámec je ve VALLEXu primárně tvořen aktanty (obligatorními i fakultativními), kvazivalenčními doplněními (obligatorními i fakultativními) a obligatorními volnými doplněními. Fakultativní volná doplnění (ač do valenčního rámce dle principů valenční teorie FGP nenáleží) jsou zachycena (především) u celých sémantických skupin lexikálních jednotek v případě, že jde o jejich prototypická rozvití; např. valenční rámec sloves kupovatimpf — koupitpf, pronajímatimpf — pronajmoutpf, najímatimpf — najmoutpf, přijímatimpf — přijmoutpf a pobíratimpf — pobratpf ve smyslu „získávat“, sestávající ze tří aktantů ACT1 PAT4 ORIGod+2, je obohacen o typické doplnění RCMPza+4.

Vedle klíčové valenční charakteristiky ve formě valenčního rámce zachycuje VALLEX řadu dalších syntaktických a syntakticko-sémantických informací, jako je kontrola či syntakticko-sémantická třída slovesa. Další informací je možnost lexikální jednotky tvořit příznakové konstrukce diatezí, reciprocity a reflexivity.

Podrobný popis slovníkového hesla uvádíme v kapitole GUIDE.

## 2 Alternace

Jeden význam slovesa je typicky charakterizován jedním valenčním rámcem. Jazyk však často umožňuje sémanticky blízké významy syntakticky strukturovat různým způsobem. Tyto rozdílné strukturace jsou manifestovány změnami ve valenční struktuře sloves, pro něž se užívá termín alternace (viz především Levin, 1993). Alternace jsou charakteristické pro vztahy mezi rozdílnými (i) povrchověsyntaktickými strukturacemi téže lexikální jednotky slovesa, např. Petr oznámil rodičům datum svatby. – Rodičům bylo (Petrem / od Petra) oznámeno datum svatby. (viz dále gramatikalizované alternace) nebo (ii) hloubkověsyntaktickými strukturacemi téhož slovesného lexému, např. Sedláci nakládali seno na vozy. – Sedláci nakládali vozy senem. (viz dále lexikalizované alternace). Alternace tak představují různorodý jazykový jev, který vyžaduje komplexní syntaktický popis. V rámci FGP byly alternace popsány zejména v pracích Panevové a Kettnerové (viz zejm. Panevová et al., 2014; Kettnerová, 2014); jejich lexikografický model byl navržen autory VALLEXu (Kettnerová et al., 2012; Kettnerová – Lopatková, 2013; Lopatková et al., 2016).

Pro účely lexikografické reprezentace alternací českých sloves ve VALLEXu vycházíme z tzv. alternačního modelu slovníku, který je založen na rozdělení lexikonu na slovníkovou (datovou) a gramatickou (pravidlovou) komponentu. V datové komponentě je každá lexikální jednotka slovesa charakterizována jedním valenčním rámcem, který popisuje tzv. nepříznakové užití dané lexikální jednotky, tedy její užití aktivní, nereflexivní a nereciproční.19 U každé relevantní lexikální jednotky slovesa je ve zvláštním atributu vyznačena možnost aplikace příslušných alternací. Gramatická komponenta, představující část celkové gramatiky jazyka, obsahuje pravidla, která popisují jednotlivé změny ve valenční struktuře sloves. Tato pravidla v případě alternací typu (i) umožňují z valenčního rámce uvedeného v datové komponentě slovníku odvodit morfematická, příp. lexikální vyjádření charakterizující příznaková užití lexikálních jednotek sloves (tedy užití pasivní, reflexivní a reciproční), v případě alternací typu (ii) umožňují určit, která valenční doplnění příslušných lexikálních jednotek odpovídají týmž situačním participantům. 20

##### Typy alternací.

Z hlediska třídění alternací se ukázala jako zásadní distinkce situačního a strukturního významu slovesa (viz především Apresjan, 1992; Mel'čuk, 2004; Kováčová, 2005; Kettnerová, 2014). Situační význam 21 představuje abstraktní model konkrétní události dějové nebo statické povahy (ať již se jedná o událost reálnou, či fiktivní); jeho jednotky (tj. účastníky situace) označujeme jako situační participanty, které zde vymezujeme víceméně intuitivně pomocí kognitivních rolí.22 Způsob, jakým jsou situační participanty jazykově strukturovány v hloubkové struktuře věty, určuje podobu strukturního významu. Strukturní význam v tomto pojetí odpovídá valenční struktuře slovesa, popisované valenčním rámcem. Jednotky strukturního významu představují jednotlivá valenční doplnění slovesa.

Každá lexikální jednotka je jedinečným způsobem charakterizována situačním a strukturním významem, tedy počtem a typem situačních participantů a valenčních doplnění, včetně jejich vzájemné korespondence, tj. uspořádání situačních participantů do valenčního rámce slovesa. Změna v situačním a/nebo strukturním významu vede k vyčlenění samostatné lexikální jednotky.

Na základě jazykových prostředků, které se na alternacích podílejí, rozlišujeme dva typy alternací, a to:

- gramatikalizované alternace, založené na užití specifických gramatických prostředků, např. Číšník vysypal popel z popelníku. – Popel z popelníku byl vysypán (od číšníka / číšníkem). či Petr potkal Marii v divadle. – Petr a Marie se potkali v divadle., a

- lexikalizované alternace, spojené se změnou lexikální jednotky, např. Číšník vysypal popel z popelníku. – Číšník vysypal popelník.

### 2.1 Gramatikalizované alternace

Gramatikalizované alternace charakterizují vztahy mezi rozdílnými povrchověsyntaktickými strukturacemi téže lexikální jednotky slovesa. Korespondence situačních participantů a valenčních doplnění je u gramatikalizovaných alternací typicky zachována,23 mění se však přiřazení valenčních doplnění povrchověsyntaktickým pozicím (Kettnerová et al., 2012; Panevová et al., 2014). Tyto změny jsou motivovány změnou hierarchizace větné struktury (Daneš, 1985).

Změny ve valenčním rámci sloves se v případě gramatikalizovaných alternací typicky omezují na změny v morfematickém vyjádření valenčních doplnění zasažených změnami v přiřazení povrchověsyntaktickým pozicím, příp. na změny v jejich lexikálním vyjádření; počet, typ i obligatornost valenčních doplnění zůstávají zachovány, srov. Obecní úřad.ACT mladé rodině.ADDR přidělil byt.PAT. – Mladá rodina.ADDR dostala (od obecního úřadu).ACT přidělen byt.PAT., kde se situační participanty „Donor“, „Recipient“ a „Objekt“ a jejich korespondence s valenčními doplněními ACT, ADDR a PAT nemění, mění se však přiřazení ACT a ADDR povrchověsyntaktickým pozicím: v prvním případě ACT obsazuje pozici subjektu a ADDR pozici nepřímého objektu, ve druhém případě je ACT odsunut do méně prominentní pozice nepřímého objektu, zatímco do prominentní pozice subjektu se přesouvá ADDR (obr. 2).

Obrázek 2: Vzájemné přiřazení situačních participantů a valenčních doplnění povrchověsyntaktickým pozicím v příkladu recipientní pasivní diateze Obecní úřad.ACT mladé rodině.ADDR přidělil byt.PAT. – Mladá rodina.ADDR dostala (od obecního úřadu).ACT přidělen byt.PAT.

Změny v morfematické formě valenčních doplnění slovesa, odrážející změny v jejich povrchověsyntaktickém vyjádření, příp. změny v jejich lexikálním obsazení, jsou v případě gramatikalizovaných alternací natolik pravidelné, že je lze popisovat pomocí formálních pravidel.

Ke gramatikalizovaným změnám v češtině jsou ve VALLEXu řazeny diateze (Lopatková et al., 2016), reflexivita a též reciprocita.

##### Diateze.

Diateze, které představují centrální typ gramatikalizovaných alternací, jsou podmíněny užitím specifického morfologického významu slovesa a jsou obvykle spojeny s odsunutím situačního participantu odpovídajícího ACT z prominentní syntaktické pozice subjektu. Panevová pro češtinu vymezuje celkem pět typů diatezí (Panevová et al., 2014):

- pasivní
  např. Evropská unie navrhla nová pravidla pro azylanty. – Evropskou unií byla navržena nová pravidla pro azylanty.

- rezultativní
  (i) typ prostý
  např. Matka uvařila babičce oběd. – Oběd (pro babičku) je (již) uvařen. / (Pro babičku) je (již) uvařeno.
  (ii) typ posesivní
  např. Matka uvařila babičce oběd. – Babička má (od matky) uvařen oběd. / Babička má (od matky) uvařeno. nebo Matka má (pro babičku) uvařen oběd. / Matka má (pro babičku) uvařeno.

- recipientní pasivní
  např. Otec zaplatil Petrovi jazykový kurz. – Petr dostal od otce zaplacen jazykový kurz.

- deagentní
  např. Radní plánovali stavbu nové školy. – Plánovala se stavba nové školy.

- dispoziční
  např. Jan studoval matematiku. – Janovi se matematika studovala lehko.

Pravidla popisující diateze jsou zachycena v gramatické komponentě slovníku, zde část GRAMMAR, kapitola GRAMMAR > 1.

##### Reflexivita.

Okrajovým typem gramatikalizovaných alternací jsou alternace spojené s vlastní (syntaktickou) reflexivitou. V reflexivních konstrukcích reflexivní osobní zájmeno vyjadřuje referenční totožnost aktantu v subjektové pozici (typicky Konatele (ACT), odd. 1) a aktantu vyjádřeného daným reflexivem, např. Petr se viděl v zrcadle. ≈ Petr viděl sám sebe (= Petra) v zrcadle. 24

Pokud je v reflexivních konstrukcích přítomen doplněk uvozený spojkou jako, dochází ve většině výskytů ke změně jeho morfematického vyjádření v závislosti na formě reflexivního osobního zájmena: v konstrukcích s dlouhou formou reflexiva sebe se doplněk shoduje s daným reflexivem (stejně jako v případě, že je daná valenční pozice vyjádřena jménem či nereflexivním osobním zájmenem), zatímco ve struktuře s klitickým reflexivem se se shoduje se subjektem. Srovnejme např. rozdíly ve shodě doplňku jako bůh / jako boha (EFF), který se v konstrukci s dlouhým reflexivem Picasso vnímal sebe.PAT jako boha.EFF umění. shoduje s objektem sebe (PAT), zatímco v konstrukcích s klitickou formou Picasso.ACT se vnímal jako bůh.EFF umění. se shoduje se subjektem Picasso (ACT) (k tomuto typu konstrukcí viz Wagner, 2014; Kettnerová et al., 2015).

Postavení této změny je v rámci gramatikalizovaných alternací výjimečné: zasažené valenční doplnění (EFF či COMPL) zůstává i při změně morfematické realizace (na rozdíl od diatezí či reciprocity) stále přiřazeno téže povrchověsyntaktické pozici, totiž doplňku. Přesto reflexivita (podobně jako diateze a reciprocita) vyvolává změny v závislostní struktuře věty, a to změnu v závislosti doplňku; mechanismus alternací je tak vhodným nástrojem pro popis i tohoto typu změny. 25

##### Reciprocita.

Na pomezí gramatikalizovaných a lexikalizovaných alternací stojí reciprocita. Tuto alternaci charakterizují – podobně jako lexikalizované alternace – změny v korespondenci situačních participantů a valenčních doplnění, z nichž vyplývají změny v povrchovém vyjádření zasažených členů valenčního rámce. Řazení reciprocity ke gramatikalizovaným alternacím však opodstatňuje hned několik skutečností: reciprocita je vyjadřována specifickými gramatickými prostředky, změny v povrchověsyntaktické strukturaci zasažených valenčních doplnění jsou dostatečně pravidelné, jejich počet ani typ se nemění.

Reciprocitu charakterizujeme jako operaci, při níž vstupují dva situační participanty (ojediněle více participantů) do vztahu symetrie. V reciproční konstrukci každý ze zasažených situačních participantů koresponduje se dvěma (či více) valenčními doplněními, srov. Petr.ACT(1) nařkl Pavla.ADDR(4) z podvodu a Pavel.ACT(1) nařkl Petra.ADDR(4) z podvodu. – (Petr a Pavel).ACT(1) se.ADDR(4) vzájemně nařkli z podvodu., kde v nereciproční konstrukci situační participanty „Mluvčí“ a „Recipient“ odpovídají po řadě valenčním doplněním Konatel (ACT) a Adresát (ADDR), zatímco v reciproční konstrukci oba tyto situační participanty odpovídají jak Konateli (ACT), tak Adresátu (ADDR); v povrchověsyntaktické struktuře je ACT vyjádřen koordinací a ADDR reflexivním osobním zájmenem v akuzativu, vyjadřujícím koreferenci s ACT (obr. 3).

Obrázek 3: Vzájemné přiřazení situačních participantů a valenčních doplnění při reciprocitě ACT a ADDR v příkladu Petr.ACT nařkl Pavla.ADDR z podvodu a Pavel.ACT nařkl Petra.ADDR z podvodu. – (Petr a Pavel).ACT se.ADDR vzájemně nařkli z podvodu.

Valenční doplnění obsazující hierarchicky výše postavenou pozici je v reciproční konstrukci vyjádřeno plurálem, koordinační skupinou, příp. kolektivem; jde buď o pozici subjektu (je-li jedno ze zasažených valenčních doplnění vyjadřováno v nerecipročních konstrukcích subjektem, srov. Petr.ACT(1) četl Marii.ADDR(3) pohádky. – (Petr a Marie).ACT(1) si (navzájem) četli pohádky.), nebo o pozici přímého objektu (není-li subjekt reciprocitou zasažen, srov. Článek porovnává prognózu.PAT(4) se skutečností.EFF(s+7) z hlediska geotechnických podmínek výstavby tunelu. – Článek porovnává (prognózu a skutečnost).PAT(4) z hlediska geotechnických podmínek výstavby tunelu.). Syntaktická pozice níže postaveného valenčního doplnění je typicky vyjádřena reflexivním osobním zájmenem v morfematickém tvaru, kterým je dané doplnění charakterizováno ve valenčním rámci popisujícím nereciproční konstrukci. Toto reflexivní osobní zájmeno je v případě, že je reciprocitou zasažen subjekt, obvykle přítomno obligatorně, srov. Petr.ACT(1) informoval Marii.ADDR(4) o výsledcích voleb. – Petr a Marie se.ADDR(4) (navzájem) informovali o výsledcích voleb. 26 V případě, že subjekt zasažen není, je syntaktická pozice níže postaveného doplnění buď fakultativní, srov. Nejsou schopni odlišit sestru.PAT(4) od bratra.ORIG(od+2). – Nejsou schopni (bratra a sestru).PAT(4) (od sebe).ORIG(od+2) odlišit., nebo je z reciproční konstrukce vypuštěna, srov. Ráda kombinuje světlé barvy.PAT(4) s tmavými barvami.EFF(s+7). – Ráda kombinuje (světlé a tmavé barvy).PAT(4).

Reciprocita je primárně signalizována výše zmíněnými změnami ve vyjádření zasažených valenčních doplnění, reflexivním osobním zájmenem a dále též adverbii spolu, navzájem, vzájemně, dohromady, příp. výrazem mezi sebou. Kombinace uvedených prostředků vyjadřujících reciprocitu je značně variabilní a je ovlivněna především skutečností, zda má sloveso reflexivní podobu, a též možností slovesa tvořit syntaktickou reflexivitu. 27

Reprezentaci reciprocity v rámci FGP popisují především Panevová (1999; 2007) a Panevová a Mikulová (2007); z významných teoretických studií uveďme zejména práce König – Gast (2008) a Nedjalkov (2007). K popisu reciprocity ve VALLEXu viz odd. GUIDE > 4.4 a kapitolu GRAMMAR > 3.

Reciproční konstrukce je možné třídit na základě valenčních doplnění vstupujících do symetrického vztahu, srov. reciprocitu ACT a ADDR v příkladu Petr a Marie se pořád hádají., ACT a PAT v příkladu Petr a Jan se vnímali jako soupeři., PAT a ORIG v příkladu Lékaři od sebe oddělili siamská dvojčata., ACT a DIR3 v příkladu Letadla se k sobě nebezpečně přiblížila. Do vztahu symetrie mohou výjimečně vstoupit i tři situační participanty (a jim odpovídající valenční doplnění), např. Petr, Jan a Pavel / Chlapci se sobě navzájem představili. 28

### 2.2 Reprezentace gramatikalizovaných alternací ve VALLEXu

##### Datová komponenta.

Lexikální jednotka slovesa vytvářející v rámci gramatikalizovaných alternací rozdílné povrchověsyntaktické strukturace je v datové komponentě lexikonu charakterizována jediným valenčním rámcem. Morfematické formy valenčních doplnění vyznačené v tomto valenčním rámci odpovídají aktivní, nereflexivní a nereciproční konstrukci,29 kterou považujeme za nepříznakový člen gramatikalizovaných alternací.

Možnost lexikálních jednotek slovesa vytvářet jednotlivé gramatikalizované alternace nelze odvodit pomocí pravidel pouze na základě jejich syntaktické struktury, jelikož je dána i jejich lexikálním významem, příp. též sémantickými rysy jmen lexikálně vyjadřujících jejich valenční doplnění. Např. slovesa přidělovatimpf — přidělitpf a odnímatimpf — odejmoutpf mají totožný valenční rámec ACT1 ADDR3 PAT4; zatímco sloveso přidělovatimpf — přidělitpf recipientní pasivní diatezi umožňuje, např. Novomanželé dostali přidělen byt., sloveso odnímatimpf — odejmoutpf do této diateze nevstupuje, např. *Dělníci dostali odňaty peníze.

Aplikovatelnost jednotlivých gramatikalizovaných alternací tak musí být u každé relevantní lexikální jednotky vyznačena v datové komponentě slovníku. Pro účely popisu gramatikalizovaných alternací jsou do slovníku VALLEX zavedeny následující atributy:

- diat pro diateze,

- refl pro vlastní (syntaktickou) reflexivitu,

- recipr pro reciprocitu.

V případě diatezí a reciprocity poskytuje současná verze slovníku VALLEX v zásadě úplnou informaci o možnostech vstupovat do alternací.30 Reflexivita je zachycena pouze v případech, kdy je možné referenční totožnost některého valenčního doplnění s aktantem v subjektové pozici vyjádřit klitickou formou reflexivního osobního zájmena (nezachycují se tedy ty případy reflexivity, ve kterých je gramatikalizována dlouhá varianta reflexiva, tedy genitiv, lokál, instrumentál a předložkové pády). Vzhledem k víceznačnosti klitik, která činí problémy jak (zejména nerodilým) mluvčím češtiny, tak při automatickém zpracování jazyka, dostala reflexivita vyjádřená klitiky v lexikografickém zpracování přednost.

Hodnoty jednotlivých atributů pro zachycení možnosti lexikální jednotky vstupovat do příslušných gramatikalizovaných alternací jsou uvedeny v odd. GUIDE > 4.2, GUIDE > 4.3 a GUIDE > 4.4.

##### Gramatická komponenta.

V gramatické komponentě slovníku (představující tu část celkové gramatiky jazyka, která bezprostředně souvisí s lexikonem) jsou uložena pravidla umožňující z nepříznakového valenčního rámce, uvedeného v datové komponentě slovníku, odvodit morfematická vyjádření pro příznaková užití lexikálních jednotek sloves (odvozený valenční rámec).31 Zdůrazněme, že v případě gramatikalizovaných alternací je počet, typ a obligatornost valenčních doplnění zachována; 32 mění se pouze morfematická vyjádření těch členů rámce, které podléhají změnám v přiřazení povrchověsyntaktickým pozicím, případně jejich vyjádření lexikální. Tyto změny jsou natolik pravidelné, že je lze popisovat formálními pravidly, která zde uvádíme v části GRAMMAR, Gramatická komponenta.

### 2.3 Lexikalizované alternace

Lexikalizované alternace spojují odlišné lexikální jednotky téhož slovesného lexému, které se vyznačují totožným situačním významem, avšak odlišují se ve strukturním významu (Panevová et al., 2014). V těchto případech je stejná množina situačních participantů pokaždé jiným způsobem rozmístěna do valenčního rámce: alternace tak umožňují strukturovat označovanou situaci pokaždé z hlediska jiného účastníka situace, srov. např. změnu v přiřazení situačních participantů „Obsah“ (mouka) a „Kontejner“ (pytle) v příkladech Jan naplnil mouku.PAT do pytlů.DIR3. – Jan naplnil pytle.PAT moukou.EFF., kde v prvním užití „Obsahu“ odpovídá PAT a „Kontejneru“ směrové doplnění Kam? DIR3, zatímco ve druhém případě jim odpovídá po řadě EFF a PAT (obr. 4). Asymetrie v korespondenci mezi situačními participanty a valenčními doplněními v důsledku vede též ke změnám v povrchověsyntaktickém vyjádření zasažených participantů.

Obrázek 4: Vzájemné přiřazení situačních participantů a valenčních doplnění v příkladu lokativní konverze Jan naplnil mouku.PAT do pytlů.DIR3. – Jan naplnil pytle.PAT moukou.EFF.

Změny ve valenčním rámci slovesa u lexikalizovaných alternací jsou velmi rozmanité, a to i v rámci homogenních sémantických skupin sloves. Tyto změny mohou zasahovat počet valenčních doplnění, jejich typ (tedy funktor) i obligatornost, srov. Vyklidili již poničené stroje a odpadky.PAT.Obsah z areálu pivovaru.DIR1.Kontejner. – Areál pivovaru.PAT.Kontejner již vyklidili od poničených strojů a odpadků.ORIG.Obsah., kde se mění jak funktory, tak obligatornost valenčních doplnění korespondujících se situačními participanty „Obsah“ a „Kontejner“, dále též Vysypal popel.PAT.Obsah z popelníku.DIR1.Kontejner. – Vysypal popelník.PAT.Kontejner., kde participant „Obsah“, přiřazený v prvním případě PAT, ve druhém případě neodpovídá žádnému valenčnímu doplnění, a tak ho nelze ani povrchově vyjádřit.

K lexikalizovaným alternacím v češtině náleží podle Kettnerové a Lopatkové (2013):

- lexikálněsémantické konverze
  např. Sedláci nakládali seno na vozy. – Sedláci nakládali vozy senem., Barva pustila z kalhot. – Kalhoty pustily (barvu).

- rozdílná strukturní realizace téhož situačního participantu
  např. Kateřina rychle sešla ze schodů dělících vyvýšenou tribunu od kolbiště. – Kateřina rychle sešla schody dělící vyvýšenou tribunu od kolbiště.

- strukturní rozpad situačního participantu na dvě valenční doplnění
  např. Petr viděl, jak Jan odchází. – Petr viděl Jana, jak odchází., Jan říkal, že je Eva chytrá. – Jan říkal o Evě, že je chytrá.

Lexikálněsémantické konverze představují centrální typ lexikalizovaných alternací; jde o konverzní změny: prominentní povrchověsyntaktická pozice subjektu nebo přímého objektu je zasažena permutací dvou situačních participantů (více viz Kettnerová, 2014). Rozdílná strukturní realizace téhož situačního participantu a strukturní rozpad situačního participantu představují alternace nekonverzní povahy, kdy je změnou zasažena pouze jedna povrchověsyntaktická pozice.

### 2.4 Reprezentace lexikalizovaných alternací ve VALLEXu

##### Datová komponenta.

Vzhledem k okolnosti, že lexikalizované alternace spojují rozdílné lexikální jednotky téhož slovesného lexému, odpovídají těmto alternacím v datové části slovníku dvě lexikální jednotky, reprezentované odlišnými valenčními rámci. U každé relevantní jednotky je zvláštním atributem vyznačena účast dané jednotky na alternaci. Pro jednotlivé typy alternací byly zavedeny následující atributy:

- conv pro lexikálněsémantické konverze,

- multiple pro rozdílnou strukturní realizaci téhož situačního participantu,

- split pro strukturní rozpad téhož situačního participantu.

Hodnotou těchto atributů je množina kognitivních rolí těch situačních participantů, které podléhají změnám v přiřazení valenčním doplněním; dále je zde pomocí symbolů I a II označeno, o kterou konstrukci z alternujícího páru se jedná. V případě atributu conv jde o dvě kognitivní role, identifikující dva situační participanty, u atributů multiple a split o roli jedinou, odpovídající jednomu participantu; např. u lexikálních jednotek slovesa nakládatimpf — naložitpf s významy „umisťovat“ a „plnit“ je vyznačen atribut conv, jehož hodnotou je dvojice kognitivních rolí „Locatum“–„Location“, srov. Sedlák nakládal seno.PAT.Locatum na vůz.DIR3.Location. – Sedlák nakládal vůz.PAT.Location senem.EFF.Locatum.; dvě lexikální jednotky slovesa vycházetimpf — vyjítpf s významem „stoupat“ spojuje atribut multiple s hodnotou „Goal“, srov. Petr rychle vyšel na kopec.DIR3.Goal. – Petr rychle vyšel kopec.PAT.Goal.; sloveso vidětimpf má u dvou lexikálních jednotek s významem „vnímat zrakem“ vyznačen atribut split s hodnotou „Stimul“, srov. Jan vidí, (že chlapec přichází).PAT.Stimul. – Jan vidí chlapce.PAT.Stimul, (že přichází).EFF.Stimul.

U každé lexikální jednotky je součástí atributu vyznačujícího některou z lexikalizovaných alternací odkaz k té lexikální jednotce, která vytváří s danou lexikální jednotkou alternující dvojici.

##### Gramatická komponenta.

V gramatické komponentě slovníku jsou uložena pravidla určující změny v korespondenci situačních participantů a valenčních doplnění, jednotlivá pravidla uvádíme v části GRAMMAR, Gramatická komponenta. Například pro výše uvedenou alternaci conv typu „Locatum“–„Location“ pravidlo zachycuje jednak změnu v korespondenci participantu „Locatum“ z PAT (v konstrukci I) na EFF (v konstrukci II), jednak změnu v korespondenci participantu „Location“ z DIR3 (v konstrukci I) na PAT (v konstrukci II); u alternace multiple „Goal“ pravidlo popisuje změnu v korespondenci daného participantu z DIR3 (v konstrukci I) na PAT (v konstrukci II) a u alternace split „Stimul“ jde o změnu v přiřazení uvedeného participantu z doplnění PAT (v konstrukci I) na dvojici doplnění PAT a EFF (v konstrukci II). Změny v povrchověsyntaktickém vyjádření situačních participantů podléhajících změnám v přiřazení valenčním doplněním jsou dány morfematickou formou vyznačenou v příslušných valenčních rámcích v datové komponentě slovníku.

### Poznámky

- ^[1] Zvláště v LFG a TAG se využívá namísto termínů valenční struktura označení (predikátová) argumentová struktura.
- ^[2] http://verbs.colorado.edu/verb-index/index.php
- ^[3] http://www.cis.edu/ treebank
- ^[4] http://verbs.colorado.edu/ mpalmer/projects/verbnet.html
- ^[5] https://verbs.colorado.edu/semlink/
- ^[6] https://framenet.icsi.berkeley.edu/fndrupal
- ^[7] http://zil.ipipan.waw.pl/Walenty
- ^[8] http://ufal.mff.cuni.cz/vallex/3.0
- ^[9] http://lindat.mff.cuni.cz/services/PDT-Vallex/
- ^[10] http://ufal.mff.cuni.cz/prague-dependency-treebank
- ^[11] Klasifikace valenčních doplnění na aktanty a volná doplnění víceméně odpovídá Tesnièrově distinkci aktanty (actants) vs. cirkumstanty (circonstants) (Tesnière, 1959). Také se v zásadě shoduje s dělením na komplementy aktantové (mimo komplementy adverbiální) a adjunkty (Grepl – Karlík, 1998; Karlík et al., 2002). V termínech Mluvnice češtiny 3 aktanty odpovídají těm participantům intenčního pole, které jsou realizovány jako subjekt nebo komplementy předmětové a kvalifikační; volná doplnění pak odpovídají komplementům adverbiálním, která mohou (viz dále obligatorní volná doplnění) i nemusí (fakultativní volná doplnění) být součástí intenčního pole (Daneš et al., 1987).
- ^[12] Doplnění MED není v současnosti ve VALLEXu zachyceno.
- ^[13] K situačním participantům viz odd. 2.
- ^[14] Jde o obligatornost na tektogramatické (významové) rovině. Na povrchověsyntaktické rovině může docházet k systémovému elidování některých členů rámce – jde především o případy zevšeobecnění aktantu, např. Do této buchty se dává sůl., Psali to v novinách., Tancovalo se do rána. (všeobecný ACT), Až Jana uvaří, půjde uklízet. (všeobecný PAT) (viz zejm. Daneš, 1971; Panevová – Řezníčková, 2001), a o systémové vypuštění obligatorního volného doplnění u některých sloves, např. Petr už odešel. (= z místa daného kontextem, DIR1). Povrchovým vypuštěním obligatorního valenčního doplnění jsou i případy aktuální elipsy, např. Odpověděl už Jan Petře na dopis? Odpověděl. (= Jan.ACT Petře.ADDR na dopis.PAT už odpověděl.).
- ^[15] U polysémních lexémů též označovaný jako hyperlexém (Filipec – Čermák, 1985).
- ^[16] V české jazykovědě označovaných též jako základní lexikální jednotky, monosémní/monosémické lexémy či lexie (Filipec – Čermák, 1985; Karlík et al., 2002).
- ^[17] Zjišťujeme, že platí nepřímo úměrný vztah mezi počtem lexémů a počtem jim odpovídajících lexikálních jednotek (a tedy valenčních rámců): největší počet slovesných lexémů má jedinou lexikální jednotku, mnoho sloves má několik málo lexikálních jednotek, naopak malé množství sloves vykazuje vysoký počet lexikálních jednotek (Žabokrtský, 2005). Obecně platí, že slovesa vyznačující se složitým valenčním chováním patří ke slovesům s vysokou frekvencí v korpusu (Bojar et al., 2005).
- ^[18] Výjimku tvoří jednak inherentně reciproční a odvozená reciproční slovesa, jednak reflexiva tantum a odvozená reflexiva, která jsou zachycena v samostatných lexikálních jednotkách, a tedy charakterizována vlastním valenčním rámcem, více viz odd. 2, GUIDE > 2.4 a GUIDE > 4.4.
- ^[19] Výjimku tvoří jednak inherentně reciproční a odvozená reciproční slovesa (Panevová, 1999; Panevová – Mikulová, 2007), jednak reflexiva tantum a odvozená reflexiva (Karlík et al., 2002), která jsou ve slovníku VALLEX zachycena v samostatných lexikálních jednotkách, více viz odd. GUIDE > 2.4 a též odd. GUIDE > 4.3 a GUIDE > 4.4.
- ^[20] Vedle termínu „valenční rámec“, explicitně popisujícího nepříznakové užití slovesa, používáme též termín „příznakový valenční rámec“, jde však jen o technické označení pro popis morfematické, příp. lexikální realizace valenčních doplnění v příznakových konstrukcích.
- ^[21] Název situační význam zde volíme pro zjednodušení výkladu s vědomím toho, že striktně vzato z hlediska FGP situační význam nepředstavuje jazykově strukturovanou část významu slovesa, ale odpovídá situačnímu (kognitivnímu) obsahu.
- ^[22] Zatímco inventář jednotek nižších jazykových rovin je více či méně spolehlivě vymezen, pro plán obsahu není ve FGP metajazyk vybudován.
- ^[23] Výjimku tvoří reciproční konstrukce, kde je vztah mezi situačními participanty a valenčními doplněními složitější, viz níže.
- ^[24] Vlastní syntaktickou reflexivitu, kterou popisujeme jako možné užití některých lexikálních jednotek, např. Petr se zranil, aby nemusel nastoupit vojenskou službu. ≈ Petr sám sebe (= Petra) zranil, aby nemusel nastoupit vojenskou službu., odlišujeme jednak od sekundární reflexivizace sloves jakožto slovotvorného procesu, který s sebou nese významovou změnu (slovesa vzniklá sekundární reflexivizací vyjadřují oproti svým nereflexivním protějškům samovolnou či bezděčnou činnost, srov. Petr se zranil při pádu ze skály., odd. GUIDE > 2.4), jednak od sekundární reciprokalizace, srov. Jan se líbal s Petrou., odd. GUIDE > 4.4. Sekundární reflexiva a reciproka zachycujeme v samostatných lexémech (Karlík et al., 2002, s. 414, více viz zde kapitolu GUIDE).
- ^[25] Pravidla popisující reflexivitu jsou zachycena v gramatické komponentě slovníku, zde část GRAMMAR, kapitola GRAMMAR > 2.
- ^[26] Výjimku tvoří některá inherentní reciproka a dále též reflexivní slovesa s dativním či genitivním ADDR, viz odd. GRAMMAR > 3.1.2.4, GRAMMAR > 3.1.2.1b a GRAMMAR > 3.1.2.3.
- ^[27] Pravidla popisující reciprocitu jsou zachycena v gramatické komponentě slovníku, zde část GRAMMAR, kapitola GRAMMAR > 3.
- ^[28] Tento typ reciprocity není pro češtinu dostatečně prozkoumán; ve slovníku VALLEX je zachycen pouze u dvou lexikálních jednotek sloves představovatimpf — představitpf a seznamovatimpf — seznámitpf.
- ^[29] Viz poznámku pod čarou 19 výše.
- ^[30] Vzhledem k velkému rozsahu dat byl pro zpracování diatezí zvolen poloautomatický přístup založený na korpusových datech a jejich předzpracování pomocí heuristických pravidel; VALLEX tak nezachycuje (teoretický) potenciál lexikálních jednotek vstupovat do jednotlivých diatezí, ale indikuje tuto možnost u těch lexikálních jednotek, u nichž se ji podařilo doložit v datech Českého národního korpusu, a to v celém nereferenčním korpusu SYN; podrobnější popis lze nalézt v práci Lopatkové et al. (2016).
- ^[31] Korpusová data dokládají možnost (alespoň v omezené míře) kombinovat různé typy gramatikalizovaných alternací, srov. Sňatek dětí byl předem dohodnut oběma rodinami. Tato možnost zatím není pro češtinu dostatečně zpracována, při pravidlovém popisu gramatikalizovaných alternací ji proto nepostihujeme (s vědomím toho, že zasluhuje další výzkum).
- ^[32] Výjimku představuje přítomnost obligatorního MANN v příznakových konstrukcích dispoziční diateze a u některých sloves též přítomnost obligatorního BEN v příznakových konstrukcích recipientní pasivní diateze.

### Seznam literatury

- Apresjan (1992)
  Apresjan, Y. D. (1992): Lexical Semantics: User's Guide to Contemporary Russian Vocabulary. Ann Arbor, MI, Karoma Publishers.
- Baker et al. (1998)
  Baker, C. F. – Fillmore, C. J. – Lowe, J. B. (1998): The Berkeley FrameNet project. In COLING-ACL’98: Proceedings of the Conference, s. 86–90, Montreal, Canada.
- Balabanova – Ivanova (2002)
  Balabanova, E. – Ivanova, K. (2002): Creating a machine-readable version of Bulgarian valence dictionary (A case study of CLaRK system application). In Hinrichs, E. – Simov, K. (ed.) Proceedings of the First Workshop on Treebanks and Linguistics Theories, s. 1–12, Sozopol, Bulgaria.
- Bojar et al. (2005)
  Bojar, O. – Semecký, J. – Benešová, V. (2005): VALEVAL: Testing VALLEX Consistency and Experimenting with Word-Frame Disambiguation. The Prague Bulletin of Mathematical Linguistics. 83, s. 5–17.
- Bresnan (1982)
  Bresnan, J. (1982): The Mental Representation of Grammatical Relations. Cambridge, MIT Press.
- Bresnan (2001)
  Bresnan, J. (2001): Lexical-Functional Syntax.: Oxford, Blackwell.
- Cruse (1986)
  Cruse, D. A. (1986): Lexical Semantics.: Cambridge, Cambridge University Press.
- Daneš (1971)
  Daneš, F. (1971): Větné členy obligatorní, potenciální a fakultativní. In Komárek, M. (ed.) Miscellanea Linguistica, 16 / Acta Universitatis Palackianae Olomucensis. Facultas philosophica. Philologica. Supplementum, s. 131–138. Ostrava, Profil.
- Daneš (1985)
  Daneš, F. (1985): Věta a text.: Praha, Academia.
- Daneš – Hlavsa (1987)
  Daneš, F. – Hlavsa, Z. (1987): Větné vzorce v češtině. Praha, Academia. (Co-authors: Jirsová, A. – Macháčková, E. – Prouzová, H. – Svozilová, N.)
- Daneš et al. (1987)
  Daneš, F. – Grepl, M. – Hlavsa, Z. (ed.) (1987): Mluvnice češtiny 3. Praha, Academia.
- Filipec – Čermák (1985)
  Filipec, J. – Čermák, F. (1985): Česká lexikologie. Praha, Academia.
- Fillmore (1968)
  Fillmore, C. J. (1968): The Case for Case.: In Bach, E. – Harms, R. T. (ed.) Universals in Linguistic Theory, s. 1–88. New York, Holt, Rinehart and Winston.
- Fillmore (1977)
  Fillmore, C. J. (1977): The Case for Case Reopened.: In Cole, P. – Sadock, J. M. (ed.) Syntax and Semantics, vol. 8: Grammatical Relations, s. 59–81. New York, Academic Press.
- Fillmore et al. (2002)
  Fillmore, C. J. – Baker, C. – Sato, H. (2002): Seeing Arguments through Transparent Structures. In Rodríguez, M. G. – Araujo, C. P. S. (ed.) Proceedings of the 3rd International Conference on Language Resources and Evaluation, LREC 2002, s. 787–791, Paris, ELRA.
- Grepl – Karlík (1998)
  Grepl, M. – Karlík, P. (1998): Skladba češtiny. Olomouc, Votobia.
- Hajič et al. (2003)
  Hajič, J. et al. (2003): PDT-VALLEX: Creating a Large-coverage Valency Lexicon for Treebank Annotation. In Nivre, J. – Hinrichs, E. (ed.) Proceedings of The Second Workshop on Treebanks and Linguistic Theories, Vol. 9, s. 57–68. (Co-authors: Panevová, J. – Urešová, Z. – Bémová, A. – Kolářová, V. – Pajas, P.).
- Hlaváčková (2008)
  Hlaváčková, D. (2008): Databáze slovesných valenčních rámců VerbaLex. Disertační práce, Brno, Masarykova univerzita v Brně, Filozofická fakulta.
- Hlaváčková – Horák (2005)
  Hlaváčková, D. – Horák, A. (2005): Transformation of WordNet Czech Valency Frames into Augmented VALLEX-1.0 Format. In Human Language Technologies as a Challenge for Computer Science and Linguistics, s. 310–313, Poznań, Wydawnictwo Poznańskie Sp. z o.o. with cooperation of Fundacja Uniwersytetu im. A. Mickiewicza.
- Ivanová et al. (2014)
  Ivanová, M. et al. (2014): Valenčný slovník slovenských slovies na korpusovom základe. Prešov, Filozofická fakulta Prešovskej univerzity v Prešove. (Co-authors: Sokolová, M. – Kyseľová, M. – Perovská, V.)
- Joshi (1985)
  Joshi, A. K. (1985): Tree adjoining grammars: How much context-sensitivity is required to provide reasonable structural descriptions? In Dowty, D. – Karttunen, L. – Zwicky, A. M. (ed.) Natural Language Parsing: Psychological, Computational, and Theoretical Perspectives, s. 206–250. Cambridge, Cambridge University Press.
- Joshi et al. (1975)
  Joshi, A. K. – Levy, L. S. – Takahashi, M. (1975): Tree Adjunct Grammars. Journal of Computer and System Sciences. 10(1), s. 136–136.
- Karlík et al. (2002)
  Karlík, P. – Nekula, M. – Pleskalová, J. (ed.) (2002): Encyklopedický slovník češtiny. Praha, Nakladatelství Lidové noviny.
- Kettnerová (2014)
  Kettnerová, V. (2014): Lexikálně-sémantické konverze ve valenčním slovníku. Praha, Karolinum.
- Kettnerová – Lopatková (2013)
  Kettnerová, V. – Lopatková, M. (2013): Lexikalizované alternace v češtině. Linguistica Copernicana. 9(1), s. 31–64.
- Kettnerová et al. (2012)
  Kettnerová, V. – Lopatková, M. – Bejček, E. (2012): The Syntax-Semantics Interface of Czech Verbs in the Valency Lexicon. In Fjeld, R. V. – Torjusen, J. M. (ed.) Proceedings of the XV EURALEX International Congress, s. 434–443, Oslo, Norway, Department of Linguistics and Scandinavian Studies, University of Oslo.
- Kettnerová et al. (2015)
  Kettnerová, V. – Lopatková, M. – Panevová, J. (2015): Shoda doplňku v reflexivních konstrukcích v češtině. Slovo a slovesnost. 76(3), s. 198–214.
- Kingsbury et al. (2002)
  Kingsbury, P. – Palmer, M. – Mitch, M. (2002): Adding Predicate Argument Structure to the Penn TreeBank. In The Second International Human Language Technology Conference, HLT-02, San Diego, CA.
- Kipper et al. (2006)
  Kipper, K. et al. (2006): Extensive Classifications of English Verbs. In Corino, E. – Marello, C. – Onesti, C. (ed.) Proceedings of the XII EURALEX International Congress, Turin. (Co-authors: Korhonen, A. – Ryant, N. – Palmer, M.).
- König – Gast (2008)
  König, E. – Gast, V. (2008): Reciprocals and Reflexives. Theoretical and Typological Explorations. Berlin – New York, Mouton de Gruyter.
- Kováčová (2005)
  Kováčová, K. (2005): Konverzívnost jako systémový vztah. Disertační práce, Praha, Univerzita Karlova v Praze, Filozofická fakulta.
- Levin (1993)
  Levin, B. C. (1993): English Verb Classes and Alternations: A Preliminary Investigation. Chicago and London, The University of Chicago Press.
- Lopatková – Panevová (2006)
  Lopatková, M. – Panevová, J. (2006): Recent Developments in the Theory of Valency in the Light of the Prague Dependency Treebank. In Šimková, M. (ed.) Insight into Slovak and Czech Corpus Linguistics, s. 83–92. Bratislava, Veda.
- Lopatková et al. (2016)
  Lopatková, M. – Vernerová, A. – Kettnerová, V. (2016): Diateze ve Valenčním slovníku českých sloves VALLEX. In Skwarska, K. (ed.) Výzkum slovesné valence ve slovanských zemích, s. 151–169. Praha, Slovanský ústav AV ČR.
- Mel'čuk (1988)
  Mel'čuk, I. A. (1988): Dependency Syntax: Theory and Practice. Albany, State University of New York Press.
- Mel'čuk (2004)
  Mel'čuk, I. A. (2004): Actants in Semantics and Syntax I.: Linguistics. 42(1), s. 1–66.
- Mel'čuk – Zholkovsky (1984)
  Mel'čuk, I. A. – Zholkovsky, A. K. (1984): Explanatory Combinatorial Dictionary of Modern Russian. Vienna, Wiener Slawistischer Almanach.
- Nedjalkov (2007)
  Nedjalkov, V. P. (2007): Typology of Reciprocal Constructions.: Amsterdam – Philadelphia, John Benjamins Publishing Company.
- Nižníková (2006)
  Nižníková, J. (2006): Valenčný slovník slovenských slovies. 2. zväzok (na korpusovom základe). Prešov, Filozofická fakulta Prešovskej univerzity v Prešove.
- Nižníková – Sokolová (1998)
  Nižníková, J. – Sokolová, M. (1998): Valenčný slovník slovenských slovies. Prešov, Filozofická fakulta Prešovskej univerzity v Prešove.
- Palmer (2009)
  Palmer, M. (2009): Semlink: Linking PropBank, VerbNet and FrameNet.: In Proceedings of the Generative Lexicon Conference, GenLex 2009, Pisa.
- Palmer et al. (2005)
  Palmer, M. – Gildea, D. – Kingsbury, P. (2005): The Proposition Bank: An Annotated Corpus of Semantic Roles. Computational Linguistics. 31(1), s. 71–106.
- Panevová (1974–75)
  Panevová, J. (1974–75): On Verbal Frames in Functional Generative Description I–II. The Prague Bulletin of Mathematical Linguistics. 22–23, s. 3–40, s. 17–52.
- Panevová (1980)
  Panevová, J. (1980): Formy a funkce ve stavbě české věty. Praha, Academia.
- Panevová (1999)
  Panevová, J. (1999): Česká reciproční zájmena a slovesná valence. Slovo a slovesnost. 60(4), s. 269–275.
- Panevová (2007)
  Panevová, J. (2007): Znovu o reciprocitě.: Slovo a slovesnost. 68(2), s. 91–100.
- Panevová et al. (2014)
  Panevová, J. et al. (2014): Mluvnice současné češtiny 2, Syntax na základě anotovaného korpusu. Praha, Karolinum. (Co-authors: Hajičová, E. – Kettnerová, V. – Lopatková, M. – Mikulová, M. – Ševčíková, M.)
- Panevová – Mikulová (2007)
  Panevová, J. – Mikulová, M. (2007): On Reciprocity. The Prague Bulletin of Mathematical Linguistics. 87, s. 27–40.
- Panevová – Řezníčková (2001)
  Panevová, J. – Řezníčková, V. (2001): K možnému pojetí všeobecnosti aktantu. In Hladká, Z. – Karlík, P. (ed.) Čeština – univerzália a specifika 3, s. 139–146.
- Polański (1980–1992)
  Polański, K. (ed.) (1980–1992): Słownik syntaktyczno-generatywny czasowników polskich. Wrocław – Kraków, Zakład Narodowy Im. Ossoliński, Instytut Języka Polskiego PAN.
- Pollard – Sag (1994)
  Pollard, C. – Sag, I. A. (1994): Head-Driven Phrase Structure Grammar. Chicago – London, University of Chicago Press.
- Popova (1987)
  Popova, M. (1987): Kratăk valenten rečnik na glagolite v săvremennia bălgarski knižoven ezik. Sofia, Bulgarian Academy of Sciences Publishing House.
- Przepiórkowski et al. (2014)
  Przepiórkowski, A. et al. (2014): Walenty: Towards a comprehensive valence dictionary of Polish. In Calzolari, N. et al. (ed.) Proceedings of the Ninth International Conference on Language Resources and Evaluation, LREC 2014, s. 2785–2792, Iceland, Reykjavík, ELRA. (Co-authors: Hajnicz, E. – Patejuk, A. – Woliński, M. – Skwarski, F. – Świdziński, M.).
- Ruppenhofer et al. (2006)
  Ruppenhofer, J. et al. (2006): FrameNet II: Extended Theory and Practice. California, Berkeley, International Computer Science Institute. (Co-authors: Ellsworth, M. – Petruck, M. R. L. – Johnson, C. R. – Scheffczyk, J.)
- Sgall (1967)
  Sgall, P. (1967): Generativní popis jazyka a česká deklinace. Praha, Academia.
- Sgall (2006)
  Sgall, P. (2006): Valence jako jádro jazykového systému.: Slovo a slovesnost. 67(3), s. 163–178.
- Sgall et al. (1986b)
  Sgall, P. et al. (1986b): Úvod do syntaxe a sémantiky. Praha, Academia. (Co-authors: Bémová, A. – Borota, J. – Hajičová, E. – Hajičová, I. – Jirků, P. – Panevová, J. – Plátek, M. – Vrbová, J.)
- Sgall et al. (1986a)
  Sgall, P. – Hajičová, E. – Panevová, J. (1986a): The Meaning of the Sentence in Its Semantic and Pragmatic Aspects. Dordrecht, Reidel.
- Skoumalová (2001)
  Skoumalová, H. (2001): Czech Syntactic Lexicon.: PhD thesis, Prague, Charles University in Prague.
- Šmilauer (1966)
  Šmilauer, V. (1966): Novočeská skladba.: Praha, SPN.
- Svozilová et al. (1997)
  Svozilová, N. – Prouzová, H. – Jirsová, A. (1997): Slovesa pro praxi. Valenční slovník nejčastějších českých sloves. Praha, Academia.
- Svozilová et al. (2005)
  Svozilová, N. – Prouzová, H. – Jirsová, A. (2005): Slovník slovesných, substantivních a adjektivních vazeb a spojení. Praha, Academia.
- Tesnière (1959)
  Tesnière, L. (1959): Eléments de syntaxe structurale.: Paris, Librairie C. Klincksieck. (Translation: Kahane, S. – Osborne, T. (2015) Elements of Structural Syntax. Amsterdam – Philadelphia, John Benjamins Publishing Company.)
- Urešová (2011)
  Urešová, Z. (2011): Valence sloves v Pražském závislostním korpusu. Praha, Ústav formální a aplikované lingvistiky.
- Wagner (2014)
  Wagner, R. (2014): A case of collision in principles of language description. The Prague Bulletin of Mathematical Linguistics. 101, s. 123–146.
- Žabokrtský (2005)
  Žabokrtský, Z. (2005): Valency Lexicon of Czech Verbs. PhD thesis, Prague, Charles University in Prague.

## Obsah